pub struct AbilityDrop {
pub template: AbilityTemplate,
pub is_new: bool,
pub evolved_from: Option<AbilityTemplate>,
pub is_checkpoint: bool,
}Fields
template: AbilityTemplateis_new: boolevolved_from: Option<AbilityTemplate>is_checkpoint: boolTrait Implementations
Sourceimpl Clone for AbilityDrop
impl Clone for AbilityDrop
Sourcefn clone(&self) -> AbilityDrop
fn clone(&self) -> AbilityDrop
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for AbilityDrop
impl CustomType for AbilityDrop
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for AbilityDrop
impl Debug for AbilityDrop
Sourceimpl<'de> Deserialize<'de> for AbilityDrop
impl<'de> Deserialize<'de> for AbilityDrop
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AbilityDrop
impl JsonSchema for AbilityDrop
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AbilityDrop
impl PartialEq for AbilityDrop
Sourceimpl Serialize for AbilityDrop
impl Serialize for AbilityDrop
Sourceimpl Tsify for AbilityDrop
impl Tsify for AbilityDrop
const DECL: &'static str = "export interface AbilityDrop {\n template: AbilityTemplate;\n is_new: boolean;\n evolved_from: AbilityTemplate | null;\n is_checkpoint: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for AbilityDrop
impl StructuralPartialEq for AbilityDrop