pub struct AbilityRarity {
pub id: AbilityRarityId,
pub name: I18nString,
pub order: u64,
pub color: String,
pub bg_color: String,
pub icon_url: String,
pub icon_path: String,
pub square_icon_path: String,
}Fields
id: AbilityRarityIdname: I18nStringorder: u64color: Stringbg_color: Stringicon_url: Stringicon_path: Stringsquare_icon_path: StringTrait Implementations
Sourceimpl Clone for AbilityRarity
impl Clone for AbilityRarity
Sourcefn clone(&self) -> AbilityRarity
fn clone(&self) -> AbilityRarity
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for AbilityRarity
impl CustomType for AbilityRarity
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for AbilityRarity
impl Debug for AbilityRarity
Sourceimpl Default for AbilityRarity
impl Default for AbilityRarity
Sourcefn default() -> AbilityRarity
fn default() -> AbilityRarity
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AbilityRarity
impl<'de> Deserialize<'de> for AbilityRarity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AbilityRarity
impl Hash for AbilityRarity
Sourceimpl JsonSchema for AbilityRarity
impl JsonSchema for AbilityRarity
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AbilityRarity
impl PartialEq for AbilityRarity
Sourceimpl Serialize for AbilityRarity
impl Serialize for AbilityRarity
Sourceimpl Tsify for AbilityRarity
impl Tsify for AbilityRarity
const DECL: &'static str = "export interface AbilityRarity {\n id: AbilityRarityId;\n name: I18nString;\n order: number;\n color: string;\n bg_color: string;\n icon_url: string;\n icon_path: string;\n square_icon_path: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for AbilityRarity
impl StructuralPartialEq for AbilityRarity