pub struct ActiveAbility {
pub ability: Ability,
pub deadline: Option<DateTime<Utc>>,
pub slot_id: Option<AbilitySlotId>,
}Fields
ability: Abilitydeadline: Option<DateTime<Utc>>slot_id: Option<AbilitySlotId>Trait Implementations
Sourceimpl Clone for ActiveAbility
impl Clone for ActiveAbility
Sourcefn clone(&self) -> ActiveAbility
fn clone(&self) -> ActiveAbility
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ActiveAbility
impl CustomType for ActiveAbility
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ActiveAbility
impl Debug for ActiveAbility
Sourceimpl<'de> Deserialize<'de> for ActiveAbility
impl<'de> Deserialize<'de> for ActiveAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActiveAbility
impl JsonSchema for ActiveAbility
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ActiveAbility
impl PartialEq for ActiveAbility
Sourceimpl Serialize for ActiveAbility
impl Serialize for ActiveAbility
Sourceimpl Tsify for ActiveAbility
impl Tsify for ActiveAbility
const DECL: &'static str = "export interface ActiveAbility {\n ability: Ability;\n deadline: DateTime<Utc> | null;\n slot_id: AbilitySlotId | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ActiveAbility